{
    "$graph": [
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/bams_markduplicates"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/bams_recalibrated"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "id": "#main/fastqc_reports"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/raw_variants"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "id": "#main/trim_reports"
                }
            ],
            "steps": [
                {
                    "run": "#files-to-directory.cwl",
                    "in": [
                        {
                            "source": "#main/bams_markduplicates",
                            "id": "#main/org_bams_markduplicates/files"
                        },
                        {
                            "default": "bams-markduplicates",
                            "id": "#main/org_bams_markduplicates/name"
                        }
                    ],
                    "out": [
                        "#main/org_bams_markduplicates/outdir"
                    ],
                    "id": "#main/org_bams_markduplicates"
                },
                {
                    "run": "#files-to-directory.cwl",
                    "in": [
                        {
                            "source": "#main/bams_recalibrated",
                            "id": "#main/org_bams_recalibrated/files"
                        },
                        {
                            "default": "bams-recalibrated",
                            "id": "#main/org_bams_recalibrated/name"
                        }
                    ],
                    "out": [
                        "#main/org_bams_recalibrated/outdir"
                    ],
                    "id": "#main/org_bams_recalibrated"
                },
                {
                    "run": "#file-pairs-to-directory.cwl",
                    "in": [
                        {
                            "source": "#main/fastqc_reports",
                            "id": "#main/org_fastqc_reports/file_pairs"
                        },
                        {
                            "default": "fastqc-reports",
                            "id": "#main/org_fastqc_reports/name"
                        }
                    ],
                    "out": [
                        "#main/org_fastqc_reports/outdir"
                    ],
                    "id": "#main/org_fastqc_reports"
                },
                {
                    "run": "#files-to-directory.cwl",
                    "in": [
                        {
                            "source": "#main/hs_metrics",
                            "id": "#main/org_hs_metrics/files"
                        },
                        {
                            "default": "hs-metrics",
                            "id": "#main/org_hs_metrics/name"
                        }
                    ],
                    "out": [
                        "#main/org_hs_metrics/outdir"
                    ],
                    "id": "#main/org_hs_metrics"
                },
                {
                    "run": "#files-to-directory.cwl",
                    "in": [
                        {
                            "source": "#main/raw_variants",
                            "id": "#main/org_raw_variants/files"
                        },
                        {
                            "default": "gvcfs",
                            "id": "#main/org_raw_variants/name"
                        }
                    ],
                    "out": [
                        "#main/org_raw_variants/outdir"
                    ],
                    "id": "#main/org_raw_variants"
                },
                {
                    "run": "#file-pairs-to-directory.cwl",
                    "in": [
                        {
                            "source": "#main/trim_reports",
                            "id": "#main/org_trim_reports/file_pairs"
                        },
                        {
                            "default": "trim-reports",
                            "id": "#main/org_trim_reports/name"
                        }
                    ],
                    "out": [
                        "#main/org_trim_reports/outdir"
                    ],
                    "id": "#main/org_trim_reports"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "Directory",
                    "outputSource": "#main/org_bams_markduplicates/outdir",
                    "id": "#main/bams_markduplicates_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/org_bams_recalibrated/outdir",
                    "id": "#main/bams_recalibrated_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/org_fastqc_reports/outdir",
                    "id": "#main/fastqc_reports_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/org_hs_metrics/outdir",
                    "id": "#main/hs_metrics_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/org_raw_variants/outdir",
                    "id": "#main/raw_variants_dir"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/org_trim_reports/outdir",
                    "id": "#main/trim_reports_dir"
                }
            ]
        },
        {
            "class": "ExpressionTool",
            "label": "Moves an array of File pairs into a named directory",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "id": "#file-pairs-to-directory.cwl/file_pairs"
                },
                {
                    "type": "string",
                    "id": "#file-pairs-to-directory.cwl/name"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "id": "#file-pairs-to-directory.cwl/outdir"
                }
            ],
            "expression": "${\n  var files = inputs.file_pairs.reduce(function(a,b) {\n      return a.concat(b);\n  }, []);\n\n  var result = {\n    outdir: {\n      class: 'Directory',\n      basename: inputs.name,\n      listing: files\n    }\n  };\n\n  return result;\n}\n",
            "id": "#file-pairs-to-directory.cwl"
        },
        {
            "class": "ExpressionTool",
            "label": "Moves an array of Files into a named directory",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#files-to-directory.cwl/files"
                },
                {
                    "type": "string",
                    "id": "#files-to-directory.cwl/name"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "id": "#files-to-directory.cwl/outdir"
                }
            ],
            "expression": "${\n  var result = {\n    outdir: {\n      class: 'Directory',\n      basename: inputs.name,\n      listing: inputs.files\n    }\n  };\n\n  return result;\n}\n",
            "id": "#files-to-directory.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
